@@ -36,7 +36,7 @@ func Run() (err error) {
 	app := cli.NewApp()
 	app.Name = "croc"
 	if Version == "" {
-		Version = "v10.0.11"
+		Version = "v10.0.12"
 	}
 	app.Version = Version
 	app.Compiled = time.Now()
@@ -392,8 +392,7 @@ func send(c *cli.Context) (err error) {
 				fmt.Printf(`On UNIX systems, to send with a custom code phrase, 
 you need to set the environmental variable CROC_SECRET:
 
-  export CROC_SECRET="****"
-  croc send file.txt
+  CROC_SECRET=**** croc send file.txt
 
 Or you can have the code phrase automatically generated:
 
@@ -609,8 +608,7 @@ func receive(c *cli.Context) (err error) {
 			fmt.Printf(`On UNIX systems, to receive with croc you either need 
 to set a code phrase using your environmental variables:
 	
-  export CROC_SECRET="****"
-  croc 
+  CROC_SECRET=**** croc 
 
 Or you can specify the code phrase when you run croc without
 declaring the secret on the command line:
