@@ -19,6 +19,7 @@ import (
 	"sync"
 	"time"
 
+	"golang.org/x/term"
 	"golang.org/x/time/rate"
 
 	"github.com/denisbrodbeck/machineid"
@@ -648,7 +649,14 @@ func (c *Client) Send(filesInfo []FileInfo, emptyFoldersToTransfer []FileInfo, t
 	if c.Options.RelayPassword != models.DEFAULT_PASSPHRASE {
 		flags.WriteString("--pass " + c.Options.RelayPassword + " ")
 	}
-	fmt.Fprintf(os.Stderr, "Code is: %[1]s\nOn the other computer run\n\ncroc %[2]s%[1]s\n", c.Options.SharedSecret, flags.String())
+	fmt.Fprintf(os.Stderr, `Code is: %[1]s
+
+On the other computer run:
+(For Windows)
+    croc %[2]s%[1]s
+(For Linux/OSX)
+    CROC_SECRET=%[1]q croc %[2]s
+`, c.Options.SharedSecret, flags.String())
 	if c.Options.Ask {
 		machid, _ := machineid.ID()
 		fmt.Fprintf(os.Stderr, "\rYour machine ID is '%s'\n", machid)
@@ -1261,6 +1269,12 @@ func (c *Client) processMessageFileInfo(m message.Message) (done bool, err error
 			}
 		}
 	}
+	// // check the totalSize does not exceed disk space
+	// usage := diskusage.NewDiskUsage(".")
+	// if usage.Available() < uint64(totalSize) {
+	// 	return true, fmt.Errorf("not enough disk space")
+	// }
+
 	// c.spinner.Stop()
 	action := "Accept"
 	if c.Options.SendingText {
@@ -1684,6 +1698,25 @@ func (c *Client) recipientGetFileReady(finished bool) (err error) {
 	return
 }
 
+func max(a int, b int) int {
+	if a > b {
+		return a
+	}
+	return b
+}
+
+func formatDescription(description string) string {
+	width, _, err := term.GetSize(int(os.Stdout.Fd()))
+	width = max(20, width-60)
+	if err != nil {
+		return description
+	}
+	if len(description) > width {
+		description = description[:(width-3)] + "..."
+	}
+	return description
+}
+
 func (c *Client) createEmptyFileAndFinish(fileInfo FileInfo, i int) (err error) {
 	log.Debugf("touching file with folder / name")
 	if !utils.Exists(fileInfo.FolderRemote) {
@@ -1721,15 +1754,12 @@ func (c *Client) createEmptyFileAndFinish(fileInfo FileInfo, i int) (err error)
 	} else {
 		description = " " + description
 	}
-	if len(description) > 20 {
-		description = description[:17] + "..."
-	}
 	c.bar = progressbar.NewOptions64(1,
 		progressbar.OptionOnCompletion(func() {
 			c.fmtPrintUpdate()
 		}),
 		progressbar.OptionSetWidth(20),
-		progressbar.OptionSetDescription(description),
+		progressbar.OptionSetDescription(formatDescription(description)),
 		progressbar.OptionSetRenderBlankState(true),
 		progressbar.OptionShowBytes(true),
 		progressbar.OptionShowCount(),
@@ -1853,12 +1883,13 @@ func (c *Client) updateState() (err error) {
 						description = c.FilesToTransfer[i].Name
 						// description = ""
 					}
+
 					c.bar = progressbar.NewOptions64(1,
 						progressbar.OptionOnCompletion(func() {
 							c.fmtPrintUpdate()
 						}),
 						progressbar.OptionSetWidth(20),
-						progressbar.OptionSetDescription(description),
+						progressbar.OptionSetDescription(formatDescription(description)),
 						progressbar.OptionSetRenderBlankState(true),
 						progressbar.OptionShowBytes(true),
 						progressbar.OptionShowCount(),
@@ -1900,16 +1931,13 @@ func (c *Client) setBar() {
 	} else if !c.Options.IsSender {
 		description = " " + description
 	}
-	if len(description) > 20 {
-		description = description[:17] + "..."
-	}
 	c.bar = progressbar.NewOptions64(
 		c.FilesToTransfer[c.FilesToTransferCurrentNum].Size,
 		progressbar.OptionOnCompletion(func() {
 			c.fmtPrintUpdate()
 		}),
 		progressbar.OptionSetWidth(20),
-		progressbar.OptionSetDescription(description),
+		progressbar.OptionSetDescription(formatDescription(description)),
 		progressbar.OptionSetRenderBlankState(true),
 		progressbar.OptionShowBytes(true),
 		progressbar.OptionShowCount(),
