@@ -23,6 +23,11 @@ type server struct {
 	banner     string
 	password   string
 	rooms      roomMap
+
+	roomCleanupInterval time.Duration
+	roomTTL             time.Duration
+
+	stopRoomCleanup chan struct{}
 }
 
 type roomInfo struct {
@@ -39,21 +44,36 @@ type roomMap struct {
 
 const pingRoom = "pinglkasjdlfjsaldjf"
 
-var timeToRoomDeletion = 10 * time.Minute
-
-// Run starts a tcp listener, run async
-func Run(debugLevel, host, port, password string, banner ...string) (err error) {
+// newDefaultServer initializes a new server, with some default configuration options
+func newDefaultServer() *server {
 	s := new(server)
+	s.roomCleanupInterval = DEFAULT_ROOM_CLEANUP_INTERVAL
+	s.roomTTL = DEFAULT_ROOM_TTL
+	s.debugLevel = DEFAULT_LOG_LEVEL
+	s.stopRoomCleanup = make(chan struct{})
+	return s
+}
+
+// RunWithOptionsAsync asynchronously starts a TCP listener.
+func RunWithOptionsAsync(host, port, password string, opts ...serverOptsFunc) error {
+	s := newDefaultServer()
 	s.host = host
 	s.port = port
 	s.password = password
-	s.debugLevel = debugLevel
-	if len(banner) > 0 {
-		s.banner = banner[0]
+	for _, opt := range opts {
+		err := opt(s)
+		if err != nil {
+			return fmt.Errorf("could not apply optional configurations: %w", err)
+		}
 	}
 	return s.start()
 }
 
+// Run starts a tcp listener, run async
+func Run(debugLevel, host, port, password string, banner ...string) (err error) {
+	return RunWithOptionsAsync(host, port, password, WithBanner(banner...), WithLogLevel(debugLevel))
+}
+
 func (s *server) start() (err error) {
 	log.SetLevel(s.debugLevel)
 	log.Debugf("starting with password '%s'", s.password)
@@ -61,24 +81,8 @@ func (s *server) start() (err error) {
 	s.rooms.rooms = make(map[string]roomInfo)
 	s.rooms.Unlock()
 
-	// delete old rooms
-	go func() {
-		for {
-			time.Sleep(timeToRoomDeletion)
-			var roomsToDelete []string
-			s.rooms.Lock()
-			for room := range s.rooms.rooms {
-				if time.Since(s.rooms.rooms[room].opened) > 3*time.Hour {
-					roomsToDelete = append(roomsToDelete, room)
-				}
-			}
-			s.rooms.Unlock()
-
-			for _, room := range roomsToDelete {
-				s.deleteRoom(room)
-			}
-		}
-	}()
+	go s.deleteOldRooms()
+	defer s.stopRoomDeletion()
 
 	err = s.run()
 	if err != nil {
@@ -173,6 +177,39 @@ func (s *server) run() (err error) {
 	}
 }
 
+// deleteOldRooms checks for rooms at a regular interval and removes those that
+// have exceeded their allocated TTL.
+func (s *server) deleteOldRooms() {
+	ticker := time.NewTicker(s.roomCleanupInterval)
+	for {
+		select {
+		case <-ticker.C:
+			var roomsToDelete []string
+			s.rooms.Lock()
+			for room := range s.rooms.rooms {
+				if time.Since(s.rooms.rooms[room].opened) > s.roomTTL {
+					roomsToDelete = append(roomsToDelete, room)
+				}
+			}
+			s.rooms.Unlock()
+
+			for _, room := range roomsToDelete {
+				s.deleteRoom(room)
+				log.Debugf("room cleaned up: %s", room)
+			}
+		case <-s.stopRoomCleanup:
+			ticker.Stop()
+			log.Debug("room cleanup stopped")
+			return
+		}
+	}
+}
+
+func (s *server) stopRoomDeletion() {
+	log.Debug("stop room cleanup fired")
+	s.stopRoomCleanup <- struct{}{}
+}
+
 var weakKey = []byte{1, 2, 3}
 
 func (s *server) clientCommunication(port string, c *comm.Comm) (room string, err error) {
